/* mod.rs
 *
 * Developed by Tim Walls <tim.walls@snowgoons.com>
 * Copyright (c) All Rights Reserved, Tim Walls
 */
//! Abstraction of the hardware devices attached to an AVR microcontroller

// Imports ===================================================================
pub mod generic;
pub mod concurrency;

#[cfg(feature="atmega4809")]
pub mod atmega4809;

#[cfg(feature="atmega328p")]
pub mod atmega328p;

